@@ -21,6 +21,7 @@ from lmfit import Minimizer, Parameters, report_fit
 from matplotlib.legend_handler import HandlerBase
 from openpyxl import load_workbook
 
+ROOT_DIR = os.path.dirname(os.path.abspath(__file__)) # This is your Project Root
 
 class OrgAlkTitration():
     """
@@ -930,22 +931,30 @@ class OrgAlkTitration():
             y_meas = dataframe["pH"]
             y_calc = dataframe["pH"]
 
-            plt.xlabel('NaOH (g)', fontsize=18)
-            plt.ylabel('pH', fontsize=18)
-            graph = plt.scatter(x_meas, y_meas, c = 'black', marker = "1")
-            graph = plt.plot(x_calc, y_calc, c = 'red')
-            plt.grid(False)
-            ax = plt.gca()
-            ax.tick_params(bottom='on', left='on', labelleft='on', labelbottom='on', length=5, labelsize = 10.5)
-            plt.rc('axes',edgecolor='black')
-            plt.annotate(f"RMS: {RMS:.5f}", xy=(0.0650, 0.75), xycoords='axes fraction')
+            for i in range(1,2):
+                plt.subplot(1,2,i)
+                rem_calc = True if i == 2 else False
+                plt.xlabel('NaOH (g)', fontsize=18)
+                plt.ylabel('pH', fontsize=18)
+                graph = plt.scatter(x_meas, y_meas - y_calc * rem_calc, c = 'black', marker = "1")
+                if rem_calc is False:
+                    graph = plt.plot(x_calc, y_calc, c = 'black')
+                else:
+                    plt.axhline(0, color='black',  linestyle='dashed', linewidth=0.85,dashes=(5, 5)) # 0
+                plt.grid(False)
+                ax = plt.gca()
+                ax.tick_params(bottom='on', left='on', labelleft='on', labelbottom='on', length=5, labelsize = 10.5)
+                plt.rc('axes',edgecolor='black')
+                if rem_calc is True:
+                    plt.annotate(f"RMS: {RMS:.5f}", xy=(0.0650, 0.75), xycoords='axes fraction')
 
-            list_color  = ["black","red",]
-            list_mak    = ["1",       "_"]
-            list_lab    = ['Measured','Calculated',]
+                list_color  = ["black","red",]
+                list_mak    = ["1",       "_"]
+                list_lab    = ['Measured','Calculated',]
+
+                ax.legend(list(zip(list_color,list_mak)), list_lab, 
+                          handler_map={tuple:MarkerHandler()}) 
 
-            ax.legend(list(zip(list_color,list_mak)), list_lab, 
-                      handler_map={tuple:MarkerHandler()}) 
 
             plt.show()
 
@@ -988,7 +997,7 @@ class OrgAlkTitration():
         output_filename = os.path.join(master_results_path,master_results_filename)
         master_results_exists = os.path.exists(output_filename)
 
-        template_results_filename = os.path.join(ROOT_DIR,"src/template_spreadsheets/master_results_template.xlsx")
+        template_results_filename = os.path.join(ROOT_DIR,"template_spreadsheets/master_results_template.xlsx")
 
         if not master_results_exists:
             print("Master Results Spreadsheet does not exist, copying from template")
